==> apache-beam-2.70.0-source-release.zip: beam-2.70.0/sdks/go/test/integration/primitives/timers_test.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package primitives

import (
	"testing"

	"github.com/apache/beam/sdks/v2/go/pkg/beam/testing/ptest"
	"github.com/apache/beam/sdks/v2/go/test/integration"
)

func TestTimers_EventTime_Bounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersEventTimeBounded)
}

func TestTimers_EventTime_Unbounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersEventTimeUnbounded)
}

func TestTimers_ProcessingTime_Infinity(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersProcessingTimeTestStream_Infinity)
}

func TestTimers_ProcessingTime_Bounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersProcessingTime_Bounded)
}

func TestTimers_ProcessingTime_Unbounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersProcessingTime_Unbounded)
}

==> apache-beam-2.71.0-source-release.zip: beam-2.71.0/sdks/go/test/integration/primitives/timers_test.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package primitives

import (
	"testing"

	"github.com/apache/beam/sdks/v2/go/pkg/beam/testing/ptest"
	"github.com/apache/beam/sdks/v2/go/test/integration"
)

func TestTimers_EventTime_Bounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersEventTimeBounded)
}

func TestTimers_EventTime_Unbounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersEventTimeUnbounded)
}

func TestTimers_EventTime_WithOutputTimestamp(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersEventTime_WithOutputTimestamp)
}

func TestTimers_EventTime_WithNoOutputTimestamp(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersEventTime_WithNoOutputTimestamp)
}

func TestTimers_ProcessingTime_Infinity(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersProcessingTimeTestStream_Infinity)
}

func TestTimers_ProcessingTime_Bounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersProcessingTime_Bounded)
}

func TestTimers_ProcessingTime_Unbounded(t *testing.T) {
	integration.CheckFilters(t)
	ptest.BuildAndRun(t, TimersProcessingTime_Unbounded)
}
